OidcPlatform class abstract
The interface that implementations of oidc must implement.
Platform implementations should extend this class
rather than implement it as Oidc.
Extending this class (using extends) ensures that the subclass will get
the default implementation, while platform implementations that implements
this interface will be broken by newly added OidcPlatform methods.
- Inheritance
-
- Object
- PlatformInterface
- OidcPlatform
- Implementers
Constructors
- OidcPlatform()
- Constructs a OidcPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAuthorizationResponse(
OidcProviderMetadata metadata, OidcAuthorizeRequest request, OidcPlatformSpecificOptions options, Map< String, dynamic> preparationResult) → Future<OidcAuthorizeResponse?> -
Returns the authorization response.
may throw an
OidcException. -
getEndSessionResponse(
OidcProviderMetadata metadata, OidcEndSessionRequest request, OidcPlatformSpecificOptions options, Map< String, dynamic> preparationResult) → Future<OidcEndSessionResponse?> -
Returns the end session response for an RP initiated logout request.
may throw an
OidcException. -
listenToFrontChannelLogoutRequests(
Uri listenOn, OidcFrontChannelRequestListeningOptions options) → Stream< OidcFrontChannelLogoutIncomingRequest> - Listens to incoming front channel logout requests. returns an empty stream on non-supported platforms.
-
monitorSessionStatus(
{required Uri checkSessionIframe, required OidcMonitorSessionStatusRequest request}) → Stream< OidcMonitorSessionResult> - starts monitoring the session status.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepareForRedirectFlow(
OidcPlatformSpecificOptions options) → Map< String, dynamic> - prepares the platform to handle a redirect flow
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ OidcPlatform
-
The default instance of OidcPlatform to use.
getter/setter pair